# ComBat multi-site harmonization in Python with neuroCombat

[![License: MIT](https://img.shields.io/github/license/Jfortin1/neuroCombat)](https://opensource.org/licenses/MIT) 
[![Version](https://img.shields.io/pypi/v/neuroCombat)](https://pypi.org/project/neuroCombat/)
[![PythonVersion](https://img.shields.io/pypi/pyversions/neuroCombat)]()


This is the maintained and official version of neuroCombat (officially hosted [here](https://github.com/ncullen93/neuroCombat), introduced in [our recent paper](https://www.sciencedirect.com/science/article/pii/S105381191730931X).


## Installation

neuroCombat is hosted on PyPI and the eaisest way to install neuroCombat is to use ```pip```:

```
pip install neuroCombat
```
